# pds.api-client
Federated PDS API which provides actionable end points standardized
between the different nodes.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: main
- Package version: 0.7.1
- Build package: org.openapitools.codegen.languages.PythonLegacyClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pds.api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pds.api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import pds.api_client
from pds.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://virtserver.swaggerhub.com/PDS_APIs/pds_federated_api/0.1.0
# See configuration.py for a list of all supported configuration parameters.
configuration = pds.api_client.Configuration(
    host = "https://virtserver.swaggerhub.com/PDS_APIs/pds_federated_api/0.1.0"
)



# Enter a context with an instance of the API client
with pds.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pds.api_client.BundlesApi(api_client)
    lidvid = 'lidvid_example' # str | lidvid (urn)

    try:
        # bundle URN resolver for lidvid, get one bundle
        api_response = api_instance.bundle_by_lidvid(lidvid)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BundlesApi->bundle_by_lidvid: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://virtserver.swaggerhub.com/PDS_APIs/pds_federated_api/0.1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BundlesApi* | [**bundle_by_lidvid**](docs/BundlesApi.md#bundle_by_lidvid) | **GET** /bundles/{lidvid} | bundle URN resolver for lidvid, get one bundle
*BundlesApi* | [**bundle_by_lidvid_all**](docs/BundlesApi.md#bundle_by_lidvid_all) | **GET** /bundles/{lidvid}/all | Get one bundle by lidvid, or all versions of a bundle by lid
*BundlesApi* | [**bundle_by_lidvid_latest**](docs/BundlesApi.md#bundle_by_lidvid_latest) | **GET** /bundles/{lidvid}/latest | bundle URN resolver for lidvid, get one bundle
*BundlesApi* | [**get_bundles**](docs/BundlesApi.md#get_bundles) | **GET** /bundles | request all PDS bundles
*BundlesCollectionsApi* | [**collections_of_a_bundle**](docs/BundlesCollectionsApi.md#collections_of_a_bundle) | **GET** /bundles/{lidvid}/collections | get collections belonging to a given bundle
*BundlesProductsApi* | [**products_of_a_bundle**](docs/BundlesProductsApi.md#products_of_a_bundle) | **GET** /bundles/{lidvid}/products | get products belonging to a given bundle
*CollectionsApi* | [**collections_by_lidvid**](docs/CollectionsApi.md#collections_by_lidvid) | **GET** /collections/{lidvid} | collections URN resolver for lidvid
*CollectionsApi* | [**collections_by_lidvid_all**](docs/CollectionsApi.md#collections_by_lidvid_all) | **GET** /collections/{lidvid}/all | Get one collection by lidvid, or all versions of a collection by lid
*CollectionsApi* | [**collections_by_lidvid_latest**](docs/CollectionsApi.md#collections_by_lidvid_latest) | **GET** /collections/{lidvid}/latest | collections URN resolver for lidvid
*CollectionsApi* | [**get_collection**](docs/CollectionsApi.md#get_collection) | **GET** /collections | request PDS collections
*CollectionsContainingBundlesApi* | [**bundles_containing_collection**](docs/CollectionsContainingBundlesApi.md#bundles_containing_collection) | **GET** /collections/{lidvid}/bundles | get bundles containing this given collection
*CollectionsProductsApi* | [**products_of_a_collection**](docs/CollectionsProductsApi.md#products_of_a_collection) | **GET** /collections/{lidvid}/products | get producs belonging to a given collection
*ProductContainingCollectionsApi* | [**collections_containing_product**](docs/ProductContainingCollectionsApi.md#collections_containing_product) | **GET** /products/{lidvid}/collections | get collections containing product
*ProductsApi* | [**products**](docs/ProductsApi.md#products) | **GET** /products | search across all PDS data products, including bundles, collections, documentation, context and observational products,
*ProductsApi* | [**products_by_lidvid**](docs/ProductsApi.md#products_by_lidvid) | **GET** /products/{lidvid} | URN resolver for lidvid
*ProductsApi* | [**products_by_lidvid_all**](docs/ProductsApi.md#products_by_lidvid_all) | **GET** /products/{lidvid}/all | Get one product by lidvid, or all versions of a product by lid
*ProductsApi* | [**products_by_lidvid_latest**](docs/ProductsApi.md#products_by_lidvid_latest) | **GET** /products/{lidvid}/latest | URN resolver for lidvid
*ProductsContainingBundlesApi* | [**bundles_containing_product**](docs/ProductsContainingBundlesApi.md#bundles_containing_product) | **GET** /products/{lidvid}/bundles | get bundles containing product


## Documentation For Models

 - [ErrorMessage](docs/ErrorMessage.md)
 - [Metadata](docs/Metadata.md)
 - [Pds4Metadata](docs/Pds4Metadata.md)
 - [Pds4MetadataDataFiles](docs/Pds4MetadataDataFiles.md)
 - [Pds4MetadataLabelFile](docs/Pds4MetadataLabelFile.md)
 - [Pds4Product](docs/Pds4Product.md)
 - [Pds4Products](docs/Pds4Products.md)
 - [Product](docs/Product.md)
 - [Products](docs/Products.md)
 - [Reference](docs/Reference.md)
 - [Summary](docs/Summary.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

pds-operator@jpl.nasa.gov


